package org.eclipse.jdt.internal.compiler.apt.dispatch;

package .tmp;

import java.lang.reflect.Field;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Locale;
import java.util.Map;
import javax.annotation.processing.Filer;
import javax.annotation.processing.Messager;
import javax.tools.JavaFileManager;
import org.eclipse.jdt.internal.compiler.apt.dispatch.BaseAnnotationProcessorManager;
import org.eclipse.jdt.internal.compiler.apt.dispatch.BaseProcessingEnvImpl;
import org.eclipse.jdt.internal.compiler.apt.dispatch.BatchFilerImpl;
import org.eclipse.jdt.internal.compiler.apt.dispatch.BatchMessagerImpl;
import org.eclipse.jdt.internal.compiler.apt.util.EclipseFileManager;
import org.eclipse.jdt.internal.compiler.batch.Main;
import org.eclipse.jdt.internal.compiler.problem.AbortCompilation;

public class BatchProcessingEnvImpl extends BaseProcessingEnvImpl {
  protected final BaseAnnotationProcessorManager _dispatchManager;
  
  protected final JavaFileManager _fileManager;
  
  protected final Main _compilerOwner;
  
  public BatchProcessingEnvImpl(BaseAnnotationProcessorManager dispatchManager, Main batchCompiler, String[] commandLineArguments) {
    this._compilerOwner = batchCompiler;
    this._compiler = batchCompiler.batchCompiler;
    this._dispatchManager = dispatchManager;
    Class<?> c = null;
    try {
      c = Class.forName("org.eclipse.jdt.internal.compiler.tool.EclipseCompilerImpl");
    } catch (ClassNotFoundException classNotFoundException) {}
    Field field = null;
    JavaFileManager javaFileManager = null;
    if (c != null)
      try {
        field = c.getField("fileManager");
      } catch (SecurityException securityException) {
      
      } catch (IllegalArgumentException illegalArgumentException) {
      
      } catch (NoSuchFieldException noSuchFieldException) {} 
    if (field != null)
      try {
        javaFileManager = (JavaFileManager)field.get(batchCompiler);
      } catch (IllegalArgumentException illegalArgumentException) {
      
      } catch (IllegalAccessException illegalAccessException) {} 
    if (javaFileManager != null) {
      this._fileManager = javaFileManager;
    } else {
      String encoding = (String)batchCompiler.options.get("org.eclipse.jdt.core.encoding");
      Charset charset = (encoding != null) ? Charset.forName(encoding) : null;
      EclipseFileManager eclipseFileManager = new EclipseFileManager(batchCompiler.compilerLocale, charset);
      ArrayList<String> options = new ArrayList<>();
      byte b;
      int i;
      String[] arrayOfString;
      for (i = (arrayOfString = commandLineArguments).length, b = 0; b < i; ) {
        String argument = arrayOfString[b];
        options.add(argument);
        b++;
      } 
      for (Iterator<String> iterator = options.iterator(); iterator.hasNext();)
        eclipseFileManager.handleOption(iterator.next(), iterator); 
      this._fileManager = (JavaFileManager)eclipseFileManager;
    } 
    this._processorOptions = Collections.unmodifiableMap(parseProcessorOptions(commandLineArguments));
    this._filer = (Filer)new BatchFilerImpl(this._dispatchManager, this);
    this._messager = (Messager)new BatchMessagerImpl(this, this._compilerOwner);
  }
  
  private Map<String, String> parseProcessorOptions(String[] args) {
    Map<String, String> options = new LinkedHashMap<>();
    byte b;
    int i;
    String[] arrayOfString;
    for (i = (arrayOfString = args).length, b = 0; b < i; ) {
      String arg = arrayOfString[b];
      if (arg.startsWith("-A")) {
        int equals = arg.indexOf('=');
        if (equals == 2) {
          Exception e = new IllegalArgumentException("-A option must have a key before the equals sign");
          throw new AbortCompilation(null, e);
        } 
        if (equals == arg.length() - 1) {
          options.put(arg.substring(2, equals), null);
        } else if (equals == -1) {
          options.put(arg.substring(2), null);
        } else {
          options.put(arg.substring(2, equals), arg.substring(equals + 1));
        } 
      } 
      b++;
    } 
    return options;
  }
  
  public JavaFileManager getFileManager() {
    return this._fileManager;
  }
  
  public Locale getLocale() {
    return this._compilerOwner.compilerLocale;
  }
}
